@@ -18,10 +18,10 @@ This file is used to store the current ``fsleyes-widgets`` version.
 """
 
 
-__version__ = '0.2.0'
+__version__ = '0.9.0'
 
 
-from fsleyes_widgets.utils import (WX_PYTHON,
+from fsleyes_widgets.utils import (WX_PYTHON,  # noqa
                                    WX_PHOENIX,
                                    wxversion,
                                    isalive)
