@@ -104,7 +104,8 @@ class EditableListBox(wx.Panel):
             labels=None,
             clientData=None,
             tooltips=None,
-            style=0):
+            style=0,
+            vgap=0):
         """Create an ``EditableListBox``.
 
         :arg parent:     :mod:`wx` parent object
@@ -122,6 +123,9 @@ class EditableListBox(wx.Panel):
                          :data:`ELB_NO_LABEL`, :data:`ELB_WIDGET_RIGHT`,
                          :data:`ELB_TOOLTIP_DOWN`, and
                          :data:`ELB_SCROLL_BUTTONS`.
+
+        :arg vgap:       Vertical gap in pixels between each item. Ignored if
+                         :data:`ELB_NO_LABEL` is set.
         """
 
         wx.Panel.__init__(self, parent, style=wx.WANTS_CHARS)
@@ -150,6 +154,7 @@ class EditableListBox(wx.Panel):
         self.__widgetOnRight = widgetOnRight
         self.__tooltipDown   = tooltipDown
         self.__scrollButtons = scrollButtons
+        self.__vgap          = vgap
 
         if labels     is None: labels     = []
         if clientData is None: clientData = [None] * len(labels)
@@ -460,13 +465,17 @@ class EditableListBox(wx.Panel):
             return
 
         nitems     = self.VisibleItemCount()
-        pageHeight = self.__listSizerSizer.GetItem(self.__listSizer) \
-                                          .GetSize().GetHeight()
+        pageHeight = self.GetSize().GetHeight() - 5
+        if self.__scrollUp is not None:
+            pageHeight -= self.__scrollUp.GetSize().GetHeight()
+        if self.__scrollDown is not None:
+            pageHeight -= self.__scrollDown.GetSize().GetHeight()
 
         # Yep, I'm assuming that all
         # items are the same size
         if nitems > 0:
-            itemHeight = self.__listItems[0].container.GetSize().GetHeight()
+            sizer      = self.__listItems[0].container.GetSizer()
+            itemHeight = sizer.CalcMin().GetHeight()
         else:
             itemHeight = 0
 
@@ -628,9 +637,12 @@ class EditableListBox(wx.Panel):
         container.SetSizer(sizer)
 
         sizerItems = [labelWidget]
-        if self.__noLabels: sizerFlags = [{}]
-        else:               sizerFlags = [{'flag'       : wx.ALIGN_CENTRE,
-                                           'proportion' : 1}]
+        if self.__noLabels:
+            sizerFlags = [{}]
+        else:
+            sizerFlags = [{'flag'       : wx.ALIGN_CENTRE | wx.BOTTOM,
+                           'border'     : self.__vgap,
+                           'proportion' : 1}]
 
         if extraWidget is not None:
             extraWidget.Reparent(container)
@@ -702,7 +714,6 @@ class EditableListBox(wx.Panel):
         self.__updateMoveButtons()
         if self.__tooltipDown: self.__configTooltipDown(item)
         else:                  self.__configTooltip(    item)
-        self.__updateScrollbar()
 
         # Make sure the enabled state of the
         # new label/widget is consistent with
@@ -850,6 +861,12 @@ class EditableListBox(wx.Panel):
         return [self.__listItems[i].data for i in indices]
 
 
+    def GetWidgets(self):
+        """Returns the widget associated with every item in the list."""
+        indices = map(self.__fixIndex, range(self.GetCount()))
+        return [self.__listItems[i].extraWidget for i in indices]
+
+
     def SetItemLabel(self, n, s):
         """Sets the label of the item at index ``n`` to the string ``s``.
 
@@ -886,23 +903,21 @@ class EditableListBox(wx.Panel):
         with the item is destroyed.
         """
 
-        item = self.__listItems[self.__fixIndex(n)]
-
-        if widget is None and item.extraWidget is None:
-            return
-
+        item  = self.__listItems[self.__fixIndex(n)]
         sizer = item.container.GetSizer()
 
         if item.extraWidget is not None:
             sizer.Detach(item.extraWidget)
             item.extraWidget.Destroy()
-
-        item.extraWidget = widget
+            item.extraWidget = None
 
         if widget is not None:
+            item.extraWidget = widget
             widget.Reparent(item.container)
             sizer.Insert(0, widget)
 
+        self.__updateScrollbar()
+
 
     def GetItemWidget(self, i):
         """Returns the widget for the item at index ``i``, or ``None``,
@@ -1230,6 +1245,7 @@ class EditableListBox(wx.Panel):
                 editCtrl.Destroy()
                 sizer.Show(listItem.labelWidget, True)
                 sizer.Layout()
+                self.Refresh()
 
             wx.CallAfter(_onFinish)
 
