@@ -10,7 +10,6 @@ modifying a floating point value.
 """
 
 
-import re
 import time
 import logging
 
@@ -51,7 +50,8 @@ class FloatSpinCtrl(FloatSpinBase):
                  value=None,
                  style=None,
                  width=None,
-                 evDelta=None):
+                 evDelta=None,
+                 precision=None):
         """Create a ``FloatSpinCtrl``.
 
         The following style flags are available:
@@ -92,6 +92,10 @@ class FloatSpinCtrl(FloatSpinBase):
                         This has the side effect that if the user clicks and
                         holds on the spin button, they have to wait <delta>
                         seconds between increments/decrements.
+
+        :arg precision: The desired precision to the right of the decimal
+                        value. Ignored if the :attr:`FSC_INTEGER` style is
+                        active.
         """
         FloatSpinBase.__init__(self, parent)
 
@@ -149,12 +153,12 @@ class FloatSpinCtrl(FloatSpinBase):
             self.__text.SetMinSize((width + 10, -1))
             self.__text.SetMaxSize((width + 10, -1))
 
-        if self.__integer:
-            self.__format      = '{:d}'
-            self.__textPattern = re.compile('^-?[0-9]*$')
-        else:
-            self.__format      = '{:.7G}'
-            self.__textPattern = re.compile('^-?[0-9]*\.?[0-9]*$')
+        if self.__integer: self.__format = '{:d}'
+        else:              self.__format = '{:.7G}'
+
+        if   self.__integer:    self.__format = '{:d}'
+        elif precision is None: self.__format = '{:.7G}'
+        else:                   self.__format = '{:.' + str(precision) + 'f}'
 
         # Events on key down, enter, focus
         # lost, and on the spin control
@@ -376,10 +380,6 @@ class FloatSpinCtrl(FloatSpinBase):
 
         val = self.__text.GetValue().strip()
 
-        if self.__textPattern.match(val) is None:
-            self.SetValue(self.__value)
-            return
-
         log.debug('Spin text - attempting to change value '
                   'from {} to {}'.format(self.__value, val))
 
@@ -389,7 +389,6 @@ class FloatSpinCtrl(FloatSpinBase):
         except ValueError:
             self.SetValue(self.__value)
             return
-
         valset = self.SetValue(val)
 
         # Add a 'changed' attribute so
